@@ -1,13 +1,13 @@
 package Net::DNS::SEC;
 
 #
-# $Id: SEC.pm 1745 2019-04-29 08:50:30Z willem $
+# $Id: SEC.pm 1759 2019-10-14 13:18:08Z willem $
 #
 our $VERSION;
-$VERSION = '1.12_02';
-our $SVNVERSION = (qw$LastChangedRevision: 1745 $)[1];
+$VERSION = '1.13_01';
+our $SVNVERSION = (qw$LastChangedRevision: 1759 $)[1];
 our $XS_VERSION = $VERSION;
-$VERSION = eval($VERSION);
+$VERSION = eval $VERSION;
 
 
 =head1 NAME
@@ -114,7 +114,7 @@ sub key_difference {
 eval { Net::DNS::SEC->bootstrap($XS_VERSION) } || warn;
 
 
-foreach (qw(DS CDS DLV RRSIG)) {
+foreach (qw(DS CDS RRSIG)) {
 	new Net::DNS::RR( type => $_ );				# pre-load to access class methods
 }
 
